import  ShakespeareTextTest (specs)
import Test.Hspec

main :: IO ()
main = hspecX [specs]
